Crate dpcs

Crate dpcs 

dpcs

Reference implementation of the Data Pipeline Contract Standard (DPCS).

Initial processing pipeline:

DPCS Document -> Parser -> Canonical Object Model -> Validator -> Diagnostics

SPEC.md is the authoritative source of truth. When implementation details are ambiguous, this crate prefers the smallest conservative behavior.

Example

use dpcs::{parse_yaml_file, validate};

let contract = parse_yaml_file("pipeline.dpcs.yaml")?;
let report = validate(&contract);
assert!(report.is_valid());

Re-exports

pub use diagnostics::Diagnostic;
pub use diagnostics::DiagnosticStage;
pub use diagnostics::Severity;
pub use diagnostics::ValidationReport;
pub use error::Error;
pub use error::Result;
pub use model::ExtensionMap;
pub use model::ExtensionValue;
pub use model::IdentityCatalog;
pub use model::InterfacePort;
pub use model::Metadata;
pub use model::ObjectId;
pub use model::ObjectKind;
pub use model::ObjectPath;
pub use model::PipelineContract;
pub use model::PipelineIdentity;
pub use model::PipelineInterface;
pub use parser::parse_json;
pub use parser::parse_json_file;
pub use parser::parse_yaml;
pub use parser::parse_yaml_file;
pub use validation::validate;

Modules

binding
Orchestrator binding framework.
capabilities
Orchestrator capability model skeleton.
cli
Command-line interface for the dpcs binary.
diagnostics
Deterministic diagnostics for DPCS processing stages.
error
Error types for parsing and I/O failures.
model
Canonical Object Model (COM) for DPCS Pipeline Contracts.
parser
YAML and JSON parsers for DPCS documents.
plan
Pipeline Plan skeleton.
validation
Phase-based validation for Pipeline Contracts.

Constants

DPCS_SPEC_VERSION
Supported DPCS specification version for this release.
VERSION
Library and CLI version string.